.. pyTelegramBotAPI documentation master file, created by
   sphinx-quickstart on Fri Feb 18 20:58:37 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to pyTelegramBotAPI's documentation!
============================================

.. meta::
   :description: Official documentation of pyTelegramBotAPI
   :keywords: ptba, pytba, pyTelegramBotAPI, documentation, guide


=======
TeleBot
=======
TeleBot is synchronous and asynchronous implementation of  `Telegram Bot API <https://core.telegram.org/bots/api>`_.

Chats
-----
English chat: `Private chat <https://telegram.me/joinchat/Bn4ixj84FIZVkwhk2jag6A>`__

Russian chat: `@pytelegrambotapi_talks_ru <https://t.me/pytelegrambotapi_talks_ru>`__

News: `@pyTelegramBotAPI <https://t.me/pytelegrambotapi>`__

Pypi: `Pypi <https://pypi.org/project/pyTelegramBotAPI/>`__

Source: `Github repository <https://github.com/eternnoir/pyTelegramBotAPI>`__

Some features:
--------------
Easy to learn and use.

Easy to understand.

Both sync and async.

Examples on features.

States

And more...

Content
--------
.. toctree::

   install
   quick_start
   types
   sync_version/index
   async_version/index
   calldata
   util
   formatting




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

   
